@@ -6,12 +6,22 @@ use std::convert::TryFrom;
 
 pub const SEED_TREASURY: &[u8] = b"treasury";
 
+/**
+ * Treasury
+ */
+
 #[account]
 #[derive(Debug)]
 pub struct Treasury {
     pub bump: u8,
 }
 
+impl Treasury {
+    pub fn pda() -> PDA {
+        Pubkey::find_program_address(&[SEED_TREASURY], &crate::ID)
+    }
+}
+
 impl TryFrom<Vec<u8>> for Treasury {
     type Error = ProgramError;
     fn try_from(data: Vec<u8>) -> Result<Self, Self::Error> {
@@ -19,8 +29,17 @@ impl TryFrom<Vec<u8>> for Treasury {
     }
 }
 
-impl Treasury {
-    pub fn pda() -> PDA {
-        Pubkey::find_program_address(&[SEED_TREASURY], &crate::ID)
+/**
+ * TreasuryAccount
+ */
+
+pub trait TreasuryAccount {
+    fn init(&mut self, bump: u8) -> ProgramResult;
+}
+
+impl TreasuryAccount for Account<'_, Treasury> {
+    fn init(&mut self, bump: u8) -> ProgramResult {
+        self.bump = bump;
+        Ok(())
     }
 }
